@@ -26,7 +26,9 @@ align = {
 }
 
 btn = {
-    'checked': ['setChecked', [int, bool]]
+    'checked': ['setChecked', [int, bool]],
+    'checkable': ['setCheckable', bool],
+    'enabled': ['setEnabled', bool]
 }
 
 ElementAttr = {
@@ -57,7 +59,6 @@ ElementAttr = {
         **size, **common, **btn,
         'shortcut': ['setShortcut', str],
         'tooltip': ['setToolTip', str],
-        'checkable': ['setCheckable', bool],
         'icon': ['setIcon', str],
         'repeat': ['setAutoRepeat', [int, bool]],
         'repeatDelay': ['setAutoRepeatDelay', int],
